from setuptools import find_packages, setup

setup(
    name='minorimpact',
    packages=find_packages(include=['minorimpact']),
    version='0.0.2',
    description='Personal utility library',
    author='Patrick Gillan',
    author_email = 'pgillan@minorimpact.com',
    license='GPLv3',
    install_requires=[],
    setup_requires=[],
    tests_require=[],
)
